import * as THREE from 'three';
import Reconciler from 'react-reconciler';
import { UseStore } from 'zustand';
import { EventHandlers } from '../three-types';
import { RootState } from './store';
export declare type Root = {
    fiber: Reconciler.FiberRoot;
    store: UseStore<RootState>;
};
export declare type LocalState = {
    root: UseStore<RootState>;
    objects: Instance[];
    instance?: boolean;
    handlers?: EventHandlers;
    dispose?: () => void;
    memoizedProps: {
        [key: string]: any;
    };
};
export declare type Instance = Omit<THREE.Object3D, 'parent' | 'children' | 'attach' | 'remove' | 'raycast'> & {
    __r3f: LocalState;
    parent: Instance | null;
    children: Instance[];
    attach?: string;
    remove: (...object: Instance[]) => Instance;
    add: (...object: Instance[]) => Instance;
    raycast?: (raycaster: THREE.Raycaster, intersects: THREE.Intersection[]) => void;
    [key: string]: any;
};
export declare type InstanceProps = {
    [key: string]: unknown;
} & {
    args?: any[];
    object?: object;
    visible?: boolean;
    dispose?: null;
    attach?: string;
};
declare let extend: (objects: object) => void;
declare function createRenderer<TCanvas, TRoot = Root>(roots: Map<TCanvas, TRoot>): {
    reconciler: Reconciler.Reconciler<unknown, unknown, unknown, unknown, unknown>;
    applyProps: (instance: Instance, newProps: InstanceProps, oldProps?: InstanceProps, accumulative?: boolean) => void;
};
export { createRenderer, extend };
