import * as THREE from 'three';
import * as React from 'react';
import * as ReactThreeFiber from '../three-types';
import { GetState, SetState, UseStore } from 'zustand';
import { Instance, InstanceProps } from './renderer';
export interface Intersection extends THREE.Intersection {
    eventObject: THREE.Object3D;
}
export declare type Subscription = {
    ref: React.MutableRefObject<RenderCallback>;
    priority: number;
};
export declare type Dpr = number | [min: number, max: number];
export declare type Size = {
    width: number;
    height: number;
};
export declare type Viewport = Size & {
    initialDpr: number;
    dpr: number;
    factor: number;
    distance: number;
    aspect: number;
};
export declare type Camera = THREE.OrthographicCamera | THREE.PerspectiveCamera;
export declare type RenderCallback = (state: RootState, delta: number) => void;
export declare type Performance = {
    current: number;
    min: number;
    max: number;
    debounce: number;
    regress: () => void;
};
export declare const isRenderer: (def: THREE.WebGLRenderer) => def is THREE.WebGLRenderer;
export declare const isOrthographicCamera: (def: THREE.Camera) => def is THREE.OrthographicCamera;
export declare type InternalState = {
    active: boolean;
    priority: number;
    frames: number;
    lastProps: StoreProps;
    events: Events;
    interaction: THREE.Object3D[];
    subscribers: Subscription[];
    captured: Intersection[] | undefined;
    initialClick: [x: number, y: number];
    initialHits: THREE.Object3D[];
    subscribe: (callback: React.MutableRefObject<RenderCallback>, priority?: number) => () => void;
};
export declare type Events = {
    click: EventListenerOrEventListenerObject;
    contextmenu: EventListenerOrEventListenerObject;
    dblclick: EventListenerOrEventListenerObject;
    wheel: EventListenerOrEventListenerObject;
    pointerdown: EventListenerOrEventListenerObject;
    pointerup: EventListenerOrEventListenerObject;
    pointerleave: EventListenerOrEventListenerObject;
    pointermove: EventListenerOrEventListenerObject;
    lostpointercapture: EventListenerOrEventListenerObject;
};
export declare type RootState = {
    gl: THREE.WebGLRenderer;
    scene: THREE.Scene & Instance;
    camera: Camera;
    raycaster: THREE.Raycaster;
    mouse: THREE.Vector2;
    clock: THREE.Clock;
    vr: boolean;
    events: boolean;
    linear: boolean;
    frameloop: boolean;
    performance: Performance;
    size: Size;
    viewport: Viewport & {
        getCurrentViewport: (camera: Camera, target: THREE.Vector3, size: Size) => Omit<Viewport, 'dpr' | 'initialDpr'>;
    };
    set: SetState<RootState>;
    get: GetState<RootState>;
    invalidate: () => void;
    setSize: (width: number, height: number) => void;
    setDpr: (dpr: Dpr) => void;
    onCreated?: (props: RootState) => void;
    onPointerMissed?: () => void;
    internal: InternalState;
};
export declare type FilterFunction = (items: THREE.Intersection[], state: RootState) => THREE.Intersection[];
export declare type ComputeOffsetsFunction = (event: any, state: RootState) => {
    offsetX: number;
    offsetY: number;
};
export declare type StoreProps = {
    gl: THREE.WebGLRenderer;
    size: Size;
    vr?: boolean;
    shadows?: boolean | Partial<THREE.WebGLShadowMap>;
    linear?: boolean;
    orthographic?: boolean;
    events?: boolean;
    frameloop?: boolean;
    performance?: Partial<Omit<Performance, 'regress'>>;
    dpr?: Dpr;
    clock?: THREE.Clock;
    raycaster?: Partial<THREE.Raycaster> & {
        filter?: FilterFunction;
        computeOffsets?: ComputeOffsetsFunction;
    };
    camera?: Camera | Partial<ReactThreeFiber.Object3DNode<THREE.Camera, typeof THREE.Camera> & ReactThreeFiber.Object3DNode<THREE.PerspectiveCamera, typeof THREE.PerspectiveCamera> & ReactThreeFiber.Object3DNode<THREE.OrthographicCamera, typeof THREE.OrthographicCamera>>;
    onCreated?: (props: RootState) => void;
    onPointerMissed?: () => void;
};
export declare type ApplyProps = (instance: Instance, newProps: InstanceProps, oldProps?: InstanceProps, accumulative?: boolean) => void;
declare const context: React.Context<UseStore<RootState>>;
declare const createStore: (applyProps: ApplyProps, invalidate: (state?: RootState | undefined) => void, props: StoreProps) => UseStore<RootState>;
export { createStore, context };
